import {UnitPrice} from '@shopify/hydrogen';
import gql from 'graphql-tag';

const QUERY = gql`
  productByHandle(handle: "my-product") {
    variants(first: 1) {
      edges {
        node {
          unitPriceMeasurement {
            measuredType
            quantityUnit
            quantityValue
            referenceUnit
            referenceValue
          }
          unitPrice {
            amount
            currencyCode
          }
        }
      }
    }
  }
`;

export default function Product() {
  const {data} = useShopQuery({query: QUERY});
  const selectedVariant = data.product.variants.edges[0].node

  return <UnitPrice unitPrice={selectedVariant.unitPrice} unitPriceMeasurement={selectedVariant.unitPriceMeasurement} />;
}

export default function ProductWithCustomUnitPrice() {
  const {data} = useShopQuery({query: QUERY});
  const selectedVariant = data.product.variants.edges[0].node

  return (
    <UnitPrice unitPrice={selectedVariant.unitPrice} unitPriceMeasurement={selectedVariant.unitPriceMeasurement}>
      {({amount, currencyCode, currencyNarrowSymbol, referenceUnit}) => {
        return (
          <>
            <span>{`${currencyNarrowSymbol}${amount}/${referenceUnit}`}</span>
            <span>{currencyCode}</span>
          </>
        );
      }}
    </UnitPrice>
  );
}
